@@ -780,7 +780,7 @@ class DataVars(object):
             header = self.__getSection(vname)
         return config.setVar(header,{vname: cl_utils.convertStrListDict(val)})
 
-    def __deleteVarValue(self, vname, location):
+    def __deleteVarValue(self, vname, location, header):
         '''Удалить переменную в calculate.ini
 
         Параметры:
@@ -809,7 +809,8 @@ class DataVars(object):
             return False
         config = iniParser(name_calculate_ini)
         # Получаем секцию конфигурационного файла
-        header = self.__getSection(vname)
+        if not header:
+            header = self.__getSection(vname)
         # Удаляем переменную
         retDelVar = config.delVar(header, vname)
         retDelArea = True
@@ -831,11 +832,13 @@ class DataVars(object):
         header      раздел ini файла ('client', 'server', 'calculate')
         '''
         if self.__Set(vname, val, force)!= False:
+            if not val.strip():
+                self.__deleteVarValue(vname, location, header)
             self.__writeVarValue(vname, val, location, header)
             return True
         return False
 
-    def Delete(self, vname, location='default'):
+    def Delete(self, vname, location='default', header=False):
         '''Удалить переменную в calculate.ini
 
         Параметры:
@@ -846,7 +849,7 @@ class DataVars(object):
         True        удалено успешна
         False       удаление не удалсь
         '''
-        return self.__deleteVarValue(vname, location)
+        return self.__deleteVarValue(vname, location, header)
 
     def __getActiveSections(self):
         """активные секции в ini файле"""
